summaryrefslogtreecommitdiff
path: root/pango/mini-fribidi
diff options
context:
space:
mode:
authorBehdad Esfahbod <behdad@behdad.org>2012-08-21 14:49:33 -0400
committerBehdad Esfahbod <behdad@behdad.org>2012-08-21 14:49:33 -0400
commitfc27e25d61bc4dec8e5598b6c2f918296b0659ed (patch)
tree8bfe2077e400762f9659718e9ffda182667e626d /pango/mini-fribidi
parent1a056db300188a8a817cd6146abd543e63ce3ba0 (diff)
downloadpango-fc27e25d61bc4dec8e5598b6c2f918296b0659ed.tar.gz
Bug 590183 - Fix bidi implementation with regards to Unicode 5.2.0
Diffstat (limited to 'pango/mini-fribidi')
-rw-r--r--pango/mini-fribidi/fribidi.c8
1 files changed, 6 insertions, 2 deletions
diff --git a/pango/mini-fribidi/fribidi.c b/pango/mini-fribidi/fribidi.c
index 08aebe31..c4644efa 100644
--- a/pango/mini-fribidi/fribidi.c
+++ b/pango/mini-fribidi/fribidi.c
@@ -494,12 +494,16 @@ fribidi_analyse_string_utf8 ( /* input */
&ored_types, &anded_strongs);
/* The case that all resolved levels will be ltr.
* First, all strongs should be ltr, and one of the following:
*
* o *pbase_dir doesn't have an rtl taste.
* o there are letters, and *pbase_dir is weak.
+ *
+ * For details see:
+ * https://bugzilla.gnome.org/show_bug.cgi?id=590183
*/
- if (!FRIBIDI_IS_RTL (ored_types) &&
+ if (!FRIBIDI_IS_RTL (ored_types) && !FRIBIDI_IS_ARABIC (ored_types) &&
(!FRIBIDI_IS_RTL (*pbase_dir) ||
(FRIBIDI_IS_WEAK (*pbase_dir) && FRIBIDI_IS_LETTER (ored_types))
))
@@ -494,12 +494,16 @@ fribidi_analyse_string_utf8 ( /* input */
&ored_types, &anded_strongs);
/* The case that all resolved levels will be ltr.
- * First, all strongs should be ltr, and one of the following:
+ * First, all strongs should be ltr, there should be no Arabic numbers
+ * (or letters for that matter), and one of the following:
*
* o *pbase_dir doesn't have an rtl taste.